**  PREABMLE from: Master file to run analysis in "The Welfare Costs of Drought in Sub-Saharan Africa" by Gascoigne et al. (2023)
clear all
set more off
program drop _all

**************************
*************** ANALYSIS - No need to change anything
***************************

***** locals

local country_name "Ethiopia"
local country1	"Ethiopia"
local radius 0
local stats "poverty_rate pov_gap_m poverty_rate_change pov_gap_change_m best_to_worse_gap"

local ppp_conv 	.7380103			// to get the payments from 2023 USD to 2011 PPP, they are adjusted by inflation (224.9/304.7) from https://www.minneapolisfed.org/about-us/monetary-policy/inflation-calculator/consumer-price-index-1913- 

loc anomaly "anomaly_rsboth_ndvi_0" //which hazard is used in the analyses
loc coef_anomaly "coef_anomaly_rsboth_ndvi_p"


*	************************************************************************
* 	1. Expand the hh_data to have the same number of years than the data on past weather and merge with hh_data
*	************************************************************************

*** Historical weather distribution
use ".\Processed_Data\Country\Pooled/`country1'_rs_ndvi0", clear

rename anomaly_rsboth_ndvi anomaly_rsboth_ndvi_0
rename anomaly_rs_ndvi anomaly_rs_ndvi_0
rename anomaly_rs2_ndvi anomaly_rs2_ndvi_0

gen anomaly_rsav_ndvi_p=(anomaly_rs_ndvi+anomaly_rs2_ndvi)/2

keep district int_month int_year anomaly_rsboth_ndvi anomaly_rs_ndvi anomaly_rs2_ndvi anomaly_rsav_ndvi

* Drop  years for which all observations are missing (none of them here)
* bys int_year: sum `anomaly'
egen year_missing = min(missing(`anomaly')), by(int_year)
drop if year_missing==1
drop if int_year==.

* Store the total number of years and the first year
distinct int_year
global year_num=`r(ndistinct)'
sum int_year
global year_min=`r(min)'-1
duplicates drop district int_year int_month , force

* Prepare for merge
tempfile weather_to_merge
rename int_year year
save `weather_to_merge', replace

clear

******** set up payouts

import excel using ".\Input_Data\For_Simulations\Ethiopia\ETH_payouts.xlsx", sheet("payout_to_stata") firstrow

reshape long y, i(district) j(year)
rename y pay
sort district year

save ".\Input_Data\For_Simulations\Ethiopia\payouts_somali.dta", replace

***merge weather, consumption and payouts

use  ".\Input_Data\Household_Survey/`country1'\Base_consumption_p_anomaly_rsboth_ndvi_p_0km_somali_v2.dta"

unique hhid

drop hhid 
gen hhid=_n

rename admin district
destring district, replace
* Drop if district is missing
drop if district==.
* Duplicate the rows to include the same number of years as in the weather data
expand $year_num
bys hhid: gen year=$year_min + _n

*** Merge
merge m:1 district year using `weather_to_merge'
keep if _merge==3
drop _merge

*** Remove years with missing values to avoid miscalculations when aggregating
drop if year==2021 | year<=2000

gen obs=1 if year==2016

merge m:1 district year using ".\Input_Data\For_Simulations\Ethiopia\payouts_somali.dta"

gen pay_ppp=pay*`ppp_conv'


*	************************************************************************
* 	2. Calculating the variables required for the EP curves
*	************************************************************************


*** Exclude the livelihoods for which we do not know the impact of weather shocks on consumption (patoral and others):

codebook livelihood
/*
            tabulation:  Freq.   Numeric  Label
                        30,459         1  Maize mixed
                         9,633         2  Agropastoral
                        15,392         3  Pastoral
                        76,518         5  Highland
                           299         6  Other


*/

drop if livelihood==.
bys livelihood: tab `coef_anomaly'

gen beneficiary=1 if district==50104		//only applying to program district and there is just one woreda with survey and program overlap

bysort district year: egen wt_total=total(pop_wt)

keep if beneficiary==1

gen included=0
replace included=1 if livelihood==3 
bys livelihood: tab included

sum pop_wt, detail

gen wt_factor=wt_total/79326			//Erer has a rural population of 79,326 (in 2015, survey collected in 2015/16) so need to adjust the weights. taken from Population Projection of Ethiopia for All Regions At Wereda Level from 2014-2017 https://www.statsethiopia.gov.et/wp-content/uploads/2019/05/Population-projection-of-Ethiopia-for-all-Regions-at-wereda-level-from-2014-2017-1.pdf

gen pop_wt_orig=pop_wt
replace pop_wt=pop_wt/wt_factor

summ pop_wt, detail

bys year: egen rural_population=total(pop_wt)
bys year livelihood: egen aez_population=total(pop_wt)
gen share_rural_pop=aez_population*100/rural_population
bys livelihood: tab aez_population

label var aez_population "Pop. in AEZ" 
label var share_rural_pop "Share of rural pop. (%)" 
label var rural_population "Total rural pop." 
label var included "Included in EP curve calc"
*/

*** Exclude the livelihoods for which the impact has not been assessed 
*** And impute the null impact in agropastoral areas if needed
drop if included==0 | `anomaly'==.


******************************
*******************************  
*******************************
**** Calculate the variables needed for the EP curves
* Generate consumption for the years in the historical weather dataset including what it would be with transfer

gen ln_consumption_sim_org=ln_base_consumption + `coef_anomaly'*`anomaly'  //this is the consumption with the shock but no program if these levels of NDVI were experienced

recode tlu_cat (1=0) (2=1) (3=4), gen(tlu)

gen ln_consumption_transfer=ln(exp(ln_consumption_sim_org)+pay_ppp*tlu)  //this is the consumption with the transfer, NOTE will be lower than without program in years where there are no payouts... 

gen ln_consumption_sim=ln_consumption_transfer

******************************************************************
****  poverty values WITHOUT program
*******************************************************************
* Cap consumption between p1 and p99 (with shock NO PROGRAM)
replace ln_consumption_sim_org=ln_cons_ppp_p1 if ln_consumption_sim_org<ln_cons_ppp_p1
replace ln_consumption_sim_org=ln_cons_ppp_p99 if ln_consumption_sim_org>ln_cons_ppp_p99

* Calculate consumption change in level and percent
gen cons_change_level_org=(exp(ln_consumption_sim_org)-exp(ln_base_consumption))
gen cons_change_pct_org=((exp(ln_consumption_sim_org)/exp(ln_base_consumption))-1)
* I calculate poverty numbers here. Note that I use the 1.9 international line but one could use the national lines by replacing ln_pl_19ppp by ln_pl_ppp

gen poverty_org=(ln_consumption_sim_org<=ln_pl_19ppp)			//hh in poverty with hazard (no program)
gen observed_poverty=(ln_consumption_observed<=ln_pl_19ppp)
gen new_poor_org=((poverty_org==1) & (observed_poverty==0))
gen new_non_poor_org=((poverty_org==0) & (observed_poverty==1))

gen pov_gap_org=exp(ln_pl_19ppp)-exp(ln_consumption_sim_org) if ln_pl_19ppp>ln_consumption_sim_org //pov gap if in poverty (bigger deeper the poverty gap)
replace pov_gap_org=0 if ln_pl_19ppp<=ln_consumption_sim_org & ln_consumption_sim_org~=. //gap is 0 if not below poverty line

gen ln_base_consumption_trunc_org=ln_base_consumption		//base conumption without any shock (truncated at 1 to 99%)
replace ln_base_consumption_trunc_org=ln_cons_ppp_p1 if ln_base_consumption<ln_cons_ppp_p1
replace ln_base_consumption_trunc_org=ln_cons_ppp_p99 if ln_base_consumption>ln_cons_ppp_p99

gen pov_base_org=(ln_base_consumption_trunc_org<=ln_pl_19ppp)  //poverty rate without any shock if truncating consumption

gen pov_gap_base_org=exp(ln_pl_19ppp)-exp(ln_base_consumption_trunc_org) if ln_pl_19ppp>ln_base_consumption_trunc_org
replace pov_gap_base_org=0 if ln_pl_19ppp<=ln_base_consumption_trunc_org & ln_base_consumption_trunc_org~=. 
//poverty gap at when no shock when consumption is truncated 

******************************************************************
****  poverty values WITH programm
*******************************************************************
* Cap consumption between p1 and p99 (with shock and program)
replace ln_consumption_sim=ln_cons_ppp_p1 if ln_consumption_sim<ln_cons_ppp_p1  
replace ln_consumption_sim=ln_cons_ppp_p99 if ln_consumption_sim>ln_cons_ppp_p99

* Calculate consumption change in level and percent
gen cons_change_level=(exp(ln_consumption_sim)-exp(ln_base_consumption))
gen cons_change_pct=((exp(ln_consumption_sim)/exp(ln_base_consumption))-1)
* I calculate poverty numbers here. Note that I use the 1.9 international line but one could use the national lines by replacing ln_pl_19ppp by ln_pl_ppp
gen poverty=(ln_consumption_sim<=ln_pl_19ppp)					// hh in poverty with hazard AND PROGRAM 
gen new_poor=((poverty==1) & (observed_poverty==0))
gen new_non_poor=((poverty==0) & (observed_poverty==1))

gen pov_gap=exp(ln_pl_19ppp)-exp(ln_consumption_sim) if ln_pl_19ppp>ln_consumption_sim
replace pov_gap=0 if ln_pl_19ppp<=ln_consumption_sim & ln_consumption_sim~=.

gen ln_base_consumption_trunc=ln_base_consumption
replace ln_base_consumption_trunc=ln_cons_ppp_p1 if ln_base_consumption<ln_cons_ppp_p1
replace ln_base_consumption_trunc=ln_cons_ppp_p99 if ln_base_consumption>ln_cons_ppp_p99

gen pov_base=(ln_base_consumption_trunc<=ln_pl_19ppp)  //poverty rate without any shock when truncating consumption.

gen pov_gap_base=exp(ln_pl_19ppp)-exp(ln_base_consumption_trunc) if ln_pl_19ppp>ln_base_consumption_trunc
replace pov_gap_base=0 if ln_pl_19ppp<=ln_base_consumption_trunc & ln_base_consumption_trunc~=. 



*	************************************************************************
* 	4. Poverty curves district
*	************************************************************************


* Generate the variables for the EP curves
collapse (first) rural_population (sum) cons_change=cons_change_level included poverty observed_poverty new_poor new_non_poor pov_gap pov_gap_base pov_base cons_change_org=cons_change_level_org poverty_org new_poor_org new_non_poor_org pov_gap_org pov_gap_base_org pov_base_org [pw=pop_wt], by(tlu_cat year)

foreach tlu_c of numlist 2 3 {
preserve 

keep if tlu_cat==`tlu_c'

** Ethiopia consumption change and poverty level by tlu category
gen cons_change_m=cons_change/1000000
gen poverty_m=poverty/1000000
gen pov_gap_m=pov_gap/1000000
gen pov_gap_base_m=pov_gap_base/1000000
gen pov_base_m=pov_base/1000000

gen cons_change_org_m=cons_change_org/1000000
gen poverty_org_m=poverty_org/1000000
gen pov_gap_org_m=pov_gap_org/1000000
gen pov_gap_base_org_m=pov_gap_base_org/1000000
gen pov_base_org_m=pov_base_org/1000000

*	************************************************************************
* 	Poverty curves
*	************************************************************************
gen poverty_rate=poverty*100/included
format poverty_rate %4.1f

gen poverty_rate_base=pov_base*100/included
format poverty_rate_base %4.1f

gen poverty_rate_change=poverty_rate-poverty_rate_base
gen pov_gap_change_m=pov_gap_m-pov_gap_base_m

gsort +pov_gap_change
gen best_to_worse_gap=_n

gen poverty_rate_org=poverty_org*100/included
format poverty_rate_org %4.1f

gen poverty_rate_base_org=pov_base_org*100/included
format poverty_rate_base_org %4.1f

gen poverty_rate_change_org=poverty_rate_org-poverty_rate_base_org
gen pov_gap_change_org_m=pov_gap_org_m-pov_gap_base_org_m

gsort +pov_gap_change_org
gen best_to_worse_gap_org=_n

 
 foreach var of varlist `stats'{
 	rename `var' `var'_sc2
 }

keep year poverty_rate_sc2 pov_gap_m_sc2 poverty_rate_change_sc2 pov_gap_change_m_sc2 best_to_worse_gap_sc2 poverty_rate_org pov_gap_org_m poverty_rate_change_org pov_gap_change_org_m best_to_worse_gap_org tlu_cat


if tlu_cat==2{
graph twoway lowess pov_gap_change_org_m best_to_worse_gap_org, lcolor(orange) lpattern(shortdash) || lowess pov_gap_change_m_sc2 best_to_worse_gap_org, ///
	lcolor(blue ) lpattern(shortdash) ///
	ytitle("Change in poverty gap (US$, Millions, 2011 PPP)", size(medsmall)) ///
	ylabel(, nogrid) ///
	xtitle(" ", size(medlarge)) xlabel(none) ///
	yline(0, lcolor(gs14)) ///
	legend(position(6) row(1) label(1 "Without policy") label(2 "With Policy")) ///
	text(-.5 3 "Good rainfall", size(medsmall)) text(-.5 9 "Average rainfall", size(medsmall)) text(-.5 16 "Bad rainfall", size(medsmall))

 graph export ".\Figures/Policy_note/Figure_3a.jpg", replace as(jpg) width(4000)
  graph export ".\Figures/Policy_note/Figure_3a.eps", replace as(eps) 

}

if tlu_cat==3{
graph twoway lowess pov_gap_change_org_m best_to_worse_gap_org, lcolor(orange) lpattern(shortdash) || lowess pov_gap_change_m_sc2 best_to_worse_gap_org, ///
	lcolor(blue ) lpattern(shortdash) graphregion(fcolor(white) color(gs16)) plotregion(fcolor(white) color(gs16)) ///
	ytitle("Change in poverty gap (US$, Millions, 2011 PPP)", size(medsmall)) ///
	ylabel(, nogrid) ///
	xtitle(" ", size(medlarge)) xlabel(none) ///
	yline(0, lcolor(gs14)) ///
	legend(position(6) row(1) label(1 "Without policy") label(2 "With Policy")) ///
	text(-2.14 3 "Good rainfall", size(medsmall)) text(-2.14 9 "Average rainfall", size(medsmall)) text(-2.14 16 "Bad rainfall", size(medsmall))

 graph export ".\Figures/Policy_note\Figure_3b.jpg", replace as(jpg) width(4000)
  graph export ".\Figures/Policy_note\Figure_3b.eps", replace as(eps) 

}

restore 
}
