**  PREABMLE from: Master file to run analysis in "The Welfare Costs of Drought in Sub-Saharan Africa" by Gascoigne et al. (2023)
clear all
set more off
program drop _all

***** locals

local country_name "Malawi"
local radius 20
local stats "poverty_rate pov_gap_m poverty_rate_change pov_gap_change_m best_to_worse_gap"

local beneficiaries "program_hh_17"


*	************************************************************************

local country1	"Malawi"
cap mkdir ".\Results/`country1'\" 

******************************************************
** 0. Determine program recipients
**************************************************

use "./Input_Data/Household_Survey/Malawi/Base_consumption_p_anomaly_swi_20km_policy.dta", clear

***id districts where applying program here using only Ntcheu 
gen program_district=1 if admin==209
keep if program_district==1

** ID households within these districts
*** for households where there is a coefficient estimate for drought, ie. only MAIZE LZ households
sort admin ln_base_consumption
by admin: gen order=_n

egen tot_pop=total(pop_wt_p) if ln_base_consumption~=., by(admin)
gen pop_share=pop_wt_p/tot_pop if ln_base_consumption~=.

gen hh_wt=pop_wt_p/hhsize

egen tot_hh=total(hh_wt) if ln_base_consumption~=., by(admin)
gen hh_share=hh_wt/tot_hh if ln_base_consumption~=.

gen hh_cum=hh_wt if order==1 & ln_base_consumption~=.
replace hh_cum=hh_cum[_n-1]+hh_wt if order>1 & ln_base_consumption~=.

gen pop_sh_cum=pop_share if order==1 & ln_base_consumption~=.
replace pop_sh_cum=pop_sh_cum[_n-1]+pop_share if order>1 & ln_base_consumption~=.

gen hh_sh_cum=hh_share if order==1 & ln_base_consumption~=.
replace hh_sh_cum=hh_sh_cum[_n-1]+hh_share if order>1 & ln_base_consumption~=.

gen program_pop_17=1 if pop_sh_cum<=0.17 & ln_base_consumption~=.
gen program_hh_17=1 if hh_sh_cum<=0.17 & ln_base_consumption~=.

gen program_hh_num=1 if hh_cum<=26346 & admin==209		//Ntcheu

keep hhid program* hhsize admin
sort hhid
save ".\Input_Data\Household_Survey/`country1'\MWI_program_recipients_ntcheu.dta", replace


*	************************************************************************
* 	1. Expand the hh_data to have the same number of years than the data on past weather and merge with hh_data
*	************************************************************************

*** Historical weather distribution
*use ".\Processed_Data\Country\Pooled/`country1'_hazards`radius'.dta", clear
use ".\Processed_Data\Country\Pooled/`country1'_swi20.dta", clear

*anomaly_swi_`radius'
keep location int_month int_year anomaly_swi_location

merge m:1 location using ".\Processed_Data\Country/`country1'\Remote_Sensed\location_lat_lon_`radius'.dta" 

drop _m

*rename anomaly_swi_`radius' anomaly_swi_location

keep if int_year>=2009

* Drop  years for which all observations are missing 
* bys int_year: sum anomaly_swi_location
egen year_missing = min(missing(anomaly_swi_location)), by(int_year)
drop if year_missing==1
drop if int_year==.

* Store the total number of years and the first year for later
distinct int_year
global year_num=`r(ndistinct)'
sum int_year
global year_min=`r(min)'-1
* Round the lon and lat to merge with household data (Note: This step follows Varun's code, but we may want to merge on uniqid instead in the future)
replace lat_modified=round(lat_modified, 0.00001)
replace lon_modified=round(lon_modified, 0.00001)
duplicates drop lat_modified lon_modified int_year int_month , force

* Prepare to merge
tempfile weather_to_merge
rename int_year year
save `weather_to_merge', replace

*** Expanding the household data
clear
use ".\Input_Data\Household_Survey/`country1'\Base_consumption_p_anomaly_swi_`radius'km_policy.dta"

* Drop if lat or lon is missing
drop if lat==. | lon==.
* Format the lat and long in the same way as the weather data variables
replace lat=round(lat, 0.00001)
replace lon=round(lon, 0.00001)
rename lat lat_modified
rename lon lon_modified
expand $year_num
bys hhid: gen year=$year_min + _n


*** Merge the datasets by coordinates, year, and interview month
merge m:1 lat_modified lon_modified year using `weather_to_merge'

keep if _merge==3
drop _merge

*** Remove years with missing values to avoid miscalculations when aggregating
drop if year==2021 | year<=2008

******************************
**** Add information on program households
***********************

merge m:1 hhid using  ".\Input_Data\Household_Survey/`country1'\MWI_program_recipients_ntcheu.dta"

tab _merge
drop _merge

*	************************************************************************
* 	2. Calculating the variables required for the EP curves
*	************************************************************************

codebook livelihood

rename coef_anomaly_swi coef_anomaly_swi_p

drop if livelihood==.
bys livelihood: tab coef_anomaly_swi_p
* The coefficient is only defined for the Maize AEZ here

* Define a variable to keep/drop the AEZ in which the impact of weather shocks is unknown: Other
gen included=0
replace included=1 if livelihood==1 | livelihood==5
bys livelihood: tab included

bys year: egen rural_population=total(pop_wt)
bys year livelihood: egen aez_population=total(pop_wt)
gen share_rural_pop=aez_population*100/rural_population
bys livelihood: tab aez_population

label var aez_population "Pop. in AEZ" 
label var share_rural_pop "Share of rural pop. (%)" 
label var rural_population "Total rural pop." 
label var included "Included in EP curve calc"

*** Exclude the livelihoods for which the impact has not been assessed 

drop if included==0 | anomaly_swi_location==.

**** Calculate the variables needed for the EP curves
* Generate consumption for the years in the historical weather dataset including what it would be with transfer

gen ln_consumption_sim_org=ln_base_consumption + coef_anomaly_swi_p*anomaly_swi_location

gen ln_consumption_transfer=ln(exp(ln_consumption_sim_org)+0.642767*30*3/hhsize)

gen ln_consumption_sim=ln_consumption_sim_org
replace ln_consumption_sim=ln_consumption_transfer if program_district==1 & `beneficiaries'==1 

******************************************************************
****  poverty values PRIOR to  transfers in 4 worst years (nationally)
*******************************************************************
* Cap consumption between p1 and p99
replace ln_consumption_sim_org=ln_cons_ppp_p1 if ln_consumption_sim_org<ln_cons_ppp_p1
replace ln_consumption_sim_org=ln_cons_ppp_p99 if ln_consumption_sim_org>ln_cons_ppp_p99

* Calculate consumption change in level and percent
gen cons_change_level_org=(exp(ln_consumption_sim_org)-exp(ln_base_consumption))
gen cons_change_pct_org=((exp(ln_consumption_sim_org)/exp(ln_base_consumption))-1)

gen poverty_org=(ln_consumption_sim_org<=ln_pl_19ppp)
gen observed_poverty=(ln_consumption_observed<=ln_pl_19ppp)
gen new_poor_org=((poverty_org==1) & (observed_poverty==0))
gen new_non_poor_org=((poverty_org==0) & (observed_poverty==1))

gen pov_gap_org=exp(ln_pl_19ppp)-exp(ln_consumption_sim_org) if ln_pl_19ppp>ln_consumption_sim_org
replace pov_gap_org=0 if ln_pl_19ppp<=ln_consumption_sim_org & ln_consumption_sim_org~=.

gen ln_base_consumption_trunc_org=ln_base_consumption
replace ln_base_consumption_trunc_org=ln_cons_ppp_p1 if ln_base_consumption<ln_cons_ppp_p1
replace ln_base_consumption_trunc_org=ln_cons_ppp_p99 if ln_base_consumption>ln_cons_ppp_p99

gen pov_base_org=(ln_base_consumption_trunc_org<=ln_pl_19ppp)

gen pov_gap_base_org=exp(ln_pl_19ppp)-exp(ln_base_consumption_trunc_org) if ln_pl_19ppp>ln_base_consumption_trunc_org
replace pov_gap_base_org=0 if ln_pl_19ppp<=ln_base_consumption_trunc_org & ln_base_consumption_trunc_org~=. 


******************************************************************
****  poverty values AFTER transfers in 4 worst years (nationally)
*******************************************************************
* Cap consumption between p1 and p99
replace ln_consumption_sim=ln_cons_ppp_p1 if ln_consumption_sim<ln_cons_ppp_p1
replace ln_consumption_sim=ln_cons_ppp_p99 if ln_consumption_sim>ln_cons_ppp_p99

* Calculate consumption change in level and percent
gen cons_change_level=(exp(ln_consumption_sim)-exp(ln_base_consumption))
gen cons_change_pct=((exp(ln_consumption_sim)/exp(ln_base_consumption))-1)

gen poverty=(ln_consumption_sim<=ln_pl_19ppp)
gen new_poor=((poverty==1) & (observed_poverty==0))
gen new_non_poor=((poverty==0) & (observed_poverty==1))

gen pov_gap=exp(ln_pl_19ppp)-exp(ln_consumption_sim) if ln_pl_19ppp>ln_consumption_sim
replace pov_gap=0 if ln_pl_19ppp<=ln_consumption_sim & ln_consumption_sim~=.

gen ln_base_consumption_trunc=ln_base_consumption
replace ln_base_consumption_trunc=ln_cons_ppp_p1 if ln_base_consumption<ln_cons_ppp_p1
replace ln_base_consumption_trunc=ln_cons_ppp_p99 if ln_base_consumption>ln_cons_ppp_p99

gen pov_base=(ln_base_consumption_trunc<=ln_pl_19ppp)

gen pov_gap_base=exp(ln_pl_19ppp)-exp(ln_base_consumption_trunc) if ln_pl_19ppp>ln_base_consumption_trunc
replace pov_gap_base=0 if ln_pl_19ppp<=ln_base_consumption_trunc & ln_base_consumption_trunc~=. 

keep if admin==209
save ".\Input_Data\Household_Survey/`country1'\MWI_simulated_pov_r`radius'_scenario2_ntcheu.dta", replace

*	************************************************************************
* 	3. Ntcheu all 
*	************************************************************************
preserve

* Generate the variables for the EP curves
collapse (first) rural_population admin (sum) cons_change=cons_change_level included poverty observed_poverty new_poor new_non_poor pov_gap pov_gap_base pov_base cons_change_org=cons_change_level_org poverty_org new_poor_org new_non_poor_org pov_gap_org pov_gap_base_org pov_base_org [pw=pop_wt], by(year)

** Malawi consumption change and poverty level
gen cons_change_m=cons_change/1000000
gen poverty_m=poverty/1000000
gen pov_gap_m=pov_gap/1000000
gen pov_gap_base_m=pov_gap_base/1000000
gen pov_base_m=pov_base/1000000

gen cons_change_org_m=cons_change_org/1000000
gen poverty_org_m=poverty_org/1000000
gen pov_gap_org_m=pov_gap_org/1000000
gen pov_gap_base_org_m=pov_gap_base_org/1000000
gen pov_base_org_m=pov_base_org/1000000


gen poverty_rate=poverty*100/included
format poverty_rate %4.1f

gen poverty_rate_base=pov_base*100/included
format poverty_rate_base %4.1f

gen poverty_rate_change=poverty_rate-poverty_rate_base
gen pov_gap_change_m=pov_gap_m-pov_gap_base_m

gsort +pov_gap_change
gen best_to_worse_gap=_n

gen poverty_rate_org=poverty_org*100/included
format poverty_rate_org %4.1f

gen poverty_rate_base_org=pov_base_org*100/included
format poverty_rate_base_org %4.1f

gen poverty_rate_change_org=poverty_rate_org-poverty_rate_base_org
gen pov_gap_change_org_m=pov_gap_org_m-pov_gap_base_org_m

gsort +pov_gap_change_org
gen best_to_worse_gap_org=_n

 foreach var of varlist `stats'{
 	rename `var' `var'_sc2
 }

keep year poverty_rate_sc2 pov_gap_m_sc2 poverty_rate_change_sc2 pov_gap_change_m_sc2 best_to_worse_gap_sc2 poverty_rate_org pov_gap_org_m poverty_rate_change_org pov_gap_change_org_m best_to_worse_gap_org admin

save ".\Input_Data\Household_Survey/`country1'\MWI_simulated_pov_r`radius'_scenario2_ntcheu1.dta", replace
restore


*	************************************************************************
* 	3. Ntcheu beneficiaries 
*	************************************************************************

keep if `beneficiaries'==1

summ rural_population cons_change* included poverty observed_poverty new_poor new_non_poor pov_gap pov_gap_base pov_base cons_change_level_org poverty_org new_poor_org new_non_poor_org pov_gap_org pov_gap_base_org pov_base_org pop_wt admin year

collapse (first) rural_population (sum) cons_change=cons_change_level included poverty observed_poverty new_poor new_non_poor pov_gap pov_gap_base pov_base cons_change_org=cons_change_level_org poverty_org new_poor_org new_non_poor_org pov_gap_org pov_gap_base_org pov_base_org [pw=pop_wt], by(admin year)


** Malawi consumption change and poverty level
gen cons_change_m=cons_change/1000000
gen poverty_m=poverty/1000000
gen pov_gap_m=pov_gap/1000000
gen pov_gap_base_m=pov_gap_base/1000000
gen pov_base_m=pov_base/1000

gen cons_change_org_ben_m=cons_change_org/1000000
gen poverty_org_ben_m=poverty_org/1000000
gen pov_gap_org_ben_m=pov_gap_org/1000000
gen pov_gap_base_org_ben_m=pov_gap_base_org/1000000
gen pov_base_org_ben_m=pov_base_org/1000000


gen poverty_rate_ben=poverty*100/included
format poverty_rate_ben %4.1f

gen poverty_rate_base_ben=pov_base*100/included
format poverty_rate_base_ben %4.1f

gen poverty_rate_change_ben=poverty_rate_ben-poverty_rate_base_ben

gen pov_gap_change_ben_m=pov_gap_m-pov_gap_base_m

gsort +pov_gap_change_ben
gen best_to_worse_gap_ben=_n

gen poverty_rate_org_ben=poverty_org*100/included
format poverty_rate_org_ben %4.1f

gen poverty_rate_base_org_ben=pov_base_org*100/included
format poverty_rate_base_org_ben %4.1f

gen poverty_rate_change_org_ben=poverty_rate_org_ben-poverty_rate_base_org_ben
gen pov_gap_change_org_ben_m=pov_gap_org_ben_m-pov_gap_base_org_ben_m

gsort +pov_gap_change_org_ben
gen best_to_worse_gap_org_ben=_n
 
rename pov_gap_m pov_gap_ben_m

local stats2 "poverty_rate_ben pov_gap_ben_m poverty_rate_change_ben pov_gap_change_ben_m best_to_worse_gap_ben" 
 foreach var of varlist `stats2'{
 	rename `var' `var'_sc2
 }

keep year poverty_rate_ben_sc2 pov_gap_ben_m_sc2 poverty_rate_change_ben_sc2 pov_gap_change_ben_m_sc2 best_to_worse_gap_ben_sc2 poverty_rate_org_ben pov_gap_org_ben_m poverty_rate_change_org_ben pov_gap_change_org_ben_m best_to_worse_gap_org_ben admin

save ".\Input_Data\Household_Survey/`country1'\MWI_simulated_pov_r`radius'_scenario2_ben_ntcheu.dta", replace

*	************************************************************************
* 	Poverty curves
*	************************************************************************

use ".\Input_Data\Household_Survey/`country1'\MWI_simulated_pov_r`radius'_scenario2_ntcheu1.dta", clear

merge 1:1 admin year using ".\Input_Data\Household_Survey/`country1'\MWI_simulated_pov_r`radius'_scenario2_ben_ntcheu.dta"
drop _merge

** simulated here is beneficiaries getting the transfer in all years, not only in bad years.  Need to adjust so that only the worst years are with the transfer

replace pov_gap_m_sc2=pov_gap_org_m if best_to_worse_gap_sc2<9
replace poverty_rate_sc2=poverty_rate_org if best_to_worse_gap_sc2<9
replace poverty_rate_change_sc2 =poverty_rate_change_org if best_to_worse_gap_sc2<9
replace pov_gap_change_m_sc2=pov_gap_change_org_m if best_to_worse_gap_sc2<9

replace pov_gap_ben_m_sc2=pov_gap_org_ben_m if best_to_worse_gap_sc2<9
replace poverty_rate_ben_sc2=poverty_rate_org_ben if best_to_worse_gap_sc2<9
replace poverty_rate_change_ben_sc2 =poverty_rate_change_org_ben if best_to_worse_gap_sc2<9
replace pov_gap_change_ben_m_sc2=pov_gap_change_org_ben_m if best_to_worse_gap_sc2<9

gen pov_gap_sc2_red=pov_gap_org_m - pov_gap_m_sc2
gen pov_rate_sc2_red=poverty_rate_org - poverty_rate_sc2

gen pov_gap_ben_sc2_red=pov_gap_org_ben_m - pov_gap_ben_m_sc2
gen pov_rate_ben_sc2_red=poverty_rate_org_ben - poverty_rate_ben_sc2

gen pov_gap_sc2_red_pct=pov_gap_sc2_red/pov_gap_org_m
gen pov_gap_ben_sc2_red_pct=pov_gap_ben_sc2_red/pov_gap_org_ben_m

sort admin best_to_worse_gap_sc2

keep year pov_gap_m_sc2 pov_gap_org_m pov_gap_change_org_m pov_gap_change_m_sc2 best_to_worse_gap_sc2 admin pov_gap_ben_m_sc2 pov_gap_org_ben_m pov_gap_change_ben_m_sc2 best_to_worse_gap_ben_sc2 pov_gap_change_org_ben_m best_to_worse_gap_org_ben pov_gap_sc2_red pov_gap_ben_sc2_red best_to_worse_gap_org best_to_worse_gap_sc2

 sort best_to_worse_gap_ben
graph twoway lowess pov_gap_change_ben_m_sc2 best_to_worse_gap_ben, lcolor(orange) lpattern(shortdash)  ||  lowess pov_gap_change_org_ben_m  best_to_worse_gap_ben, lcolor(blue) lpattern(shortdash)  ///
	ytitle("Change in poverty gap (US$, Millions, 2011 PPP)", size(medsmall)) ///
	ylabel(, nogrid) ///
	xtitle(" ", size(medlarge)) xlabel(none) ///
	yline(0, lcolor(gs14)) ///
	legend(position(6) row(1) label(1 "With policy") label(2 "Without Policy")) ///
	text(-2.3 3 "Good rainfall", size(medsmall)) text(-2.3 7 "Average rainfall", size(medsmall)) text(-2.3 11 "Bad rainfall", size(medsmall))

 graph export ".\Figures/Policy_note\Figure_4.jpg", replace as(jpg) width(4000)
  graph export ".\Figures/Policy_note\Figure_4.eps", replace as(eps) 

sort best_to_worse_gap_sc2
graph twoway lowess pov_gap_change_m_sc2 best_to_worse_gap_sc2, lcolor(orange) lpattern(shortdash)  ||  lowess pov_gap_change_org_m  best_to_worse_gap_sc2, lcolor(blue) lpattern(shortdash)  ///
	ytitle("Change in poverty gap (US$, Millions, 2011 PPP)", size(medsmall)) ///
	ylabel(-15(5)15)  ///
	xtitle(" ", size(medlarge)) xlabel(none) ///
	yline(0, lcolor(gs14)) ///
	legend(position(6) row(1) label(1 "With policy") label(2 "Without Policy")) ///
	text(-17 3 "Good rainfall", size(medsmall)) text(-17 7 "Average rainfall", size(medsmall)) text(-17 11 "Bad rainfall", size(medsmall))

 graph export ".\Figures/Policy_note\Figure_5.jpg", replace as(jpg) width(4000)
  graph export ".\Figures/Policy_note\Figure_5.eps", replace as(eps)

 